@@ -53,8 +53,8 @@ class Pep8Plugin(AbstractPythonPlugin):
                                                 us_env=True,
                                                 ignore_returncodes=[127])
         if value == 0:
-            return "pep8: %s"%output
-        raise UnilintPluginInitException("ERROR Cannot find pep8, install via apt or pip\n%s"%message)
+            return "pep8: %s" % output
+        raise UnilintPluginInitException("ERROR Cannot find pep8, install via apt or pip\n%s" % message)
 
     def check_resource(self, options, path, type_categories):
         if (not 'python-src' in type_categories and
@@ -76,7 +76,7 @@ class Pep8Plugin(AbstractPythonPlugin):
         if options.level < LEVELS[LEVEL_STYLE]:
             levels.append('W')
 
-        cmd = "pep8 %s -r --select=%s"%(path, ','.join(levels))
+        cmd = "pep8 %s -r --select=%s" % (path, ','.join(levels))
 
         if options.verbose:
             print(cmd)
@@ -89,9 +89,10 @@ class Pep8Plugin(AbstractPythonPlugin):
             print output
             return None
         else:
-            return self.parse(output)
+            basepath = os.path.dirname(path)
+            return self.parse(output, basepath)
 
-    def parse(self, output):
+    def parse(self, output, basepath):
         issues = []
         for line in output.splitlines():
             if line.strip() == '':
@@ -104,7 +105,7 @@ class Pep8Plugin(AbstractPythonPlugin):
             if category.startswith('W'):
                 severity = "style"
 
-            issue = Issue(path=tokens[0],
+            issue = Issue(path=os.path.join(basepath, tokens[0]),
                           message=message,
                           checker_id=self.get_id(),
                           line_number_start=tokens[1],
