@@ -31,7 +31,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import os
-from unilint.python_source_plugin import AbstractPythonPlugin, PYFILE_FIND_COMMAND_ARGS
+from unilint.python_source_plugin import AbstractPythonPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
 from unilint.issue import Issue
 
@@ -49,8 +49,8 @@ class PyflakesPlugin(AbstractPythonPlugin):
         try:
             import pyflakes
         except ImportError as e:
-            raise UnilintPluginInitException("ERROR Cannot find pyflakes, install via apt or pip\n%s"%e)
-        return "pyflakes: %s"%pyflakes.__version__
+            raise UnilintPluginInitException("ERROR Cannot find pyflakes, install via apt or pip\n%s" % e)
+        return "pyflakes: %s" % pyflakes.__version__
 
     @classmethod
     def is_enabled_by_default(cls):
@@ -59,20 +59,15 @@ class PyflakesPlugin(AbstractPythonPlugin):
 
     def check_resource(self, options, path, type_categories):
         if (not 'python-src' in type_categories and
-            not 'script' in type_categories and
-            not 'python-module' in type_categories):
+            not 'script' in type_categories):
             return None
 
-        if 'python-src' in type_categories or 'python-module' in type_categories:
-            cmd = "find %s %s | xargs pyflakes"%(path, PYFILE_FIND_COMMAND_ARGS)
-        else:
-            cmd = "pyflakes %s"%path
+        cmd = "pyflakes %s"%path
         if options.verbose:
             print(cmd)
         _, output, _ = self.shell_cmd(cmd,
                                       shell=True,
-                                      us_env=True,
-                                      cwd=os.path.dirname(path))
+                                      us_env=True)
         if options.raw:
             print output
             return None
